import * as _ from 'lodash';
import { unixIndexMapCalculations } from '../calculations/unix-index-map';
import { csvLoadingCalculations as csvCalculations } from './calculations';
import { EnumTimeSeriesType } from '../state/enums';
export var csvLoadingAuxiliary = {
    /**
     * Returns a new, updated IChartState and ITimeSeries that was created and added to IChartState
     */
    startedLoadingCsvData: function (state) {
        return _.extend({}, state, {
            series: []
        });
    },
    /**
     * Returns a new, updated IChartState and ITimeSeries that was created and added to IChartState
     */
    receivedCsvDataChunk: function (state, appendRows, csvRows, csvExtractConfig) {
        if (csvRows.length == 0)
            return [state, state.series.length > 0 ? _.first(state.series) : null];
        var points = csvCalculations.extractUnixTimePoints(csvRows, csvExtractConfig);
        var timeSeries = {
            color: "steelblue",
            name: "csv_loaded_series_" + (state.series.length + 1),
            points: appendRows ?
                (state.series.length == 0 ? points : _.concat(_.first(state.series).points, points)) :
                points,
            unixFrom: appendRows ?
                (state.series.length == 0 ? _.first(points).unix : _.first(state.series).unixFrom) :
                _.first(points).unix,
            unixTo: _.last(points).unix,
            type: EnumTimeSeriesType.DottedLine
        };
        timeSeries.unixToIndexMap = unixIndexMapCalculations.createUnixToIndexMap(timeSeries.points);
        var chartState = _.extend({}, state, {
            series: [timeSeries]
        });
        chartState.dateRangeUnixFrom = timeSeries.unixFrom;
        chartState.dateRangeUnixTo = timeSeries.unixTo;
        chartState.windowUnixFrom = timeSeries.unixFrom;
        chartState.windowUnixTo = timeSeries.unixTo;
        chartState.yMin = _.min(_.map(timeSeries.points, function (el) { return el.value; }));
        chartState.yMax = _.max(_.map(timeSeries.points, function (el) { return el.value; }));
        return [chartState, timeSeries];
    }
};
//# sourceMappingURL=auxiliary.js.map