import * as React from 'react';
import * as d3 from 'd3';
import * as _ from 'lodash';
import { hpTimeSeriesChartCalculations } from './calculations';
import { TimeSeries } from './components/time-series';
import { DateTimeAxis } from './components/date-time-axis';
import { ValueAxis } from './components/value-axis';
export var EnumHpTimeSeriesChartMode;
(function (EnumHpTimeSeriesChartMode) {
    EnumHpTimeSeriesChartMode[EnumHpTimeSeriesChartMode["Standalone"] = 0] = "Standalone";
    EnumHpTimeSeriesChartMode[EnumHpTimeSeriesChartMode["SliderEmbedded"] = 1] = "SliderEmbedded";
})(EnumHpTimeSeriesChartMode || (EnumHpTimeSeriesChartMode = {}));
export var HpTimeSeriesChart = function (props) {
    var getStyle = function () {
        if (_.isUndefined(props.mode))
            return {};
        switch (props.mode) {
            case EnumHpTimeSeriesChartMode.Standalone:
                return {};
            case EnumHpTimeSeriesChartMode.SliderEmbedded:
                return {
                    position: "absolute"
                };
        }
    };
    var displayAxis = function () {
        return (_.isUndefined(props.mode) || (props.mode == EnumHpTimeSeriesChartMode.Standalone));
    };
    var getXScale = function () {
        return d3.scaleTime()
            .domain([props.state.windowUnixFrom, props.state.windowUnixTo])
            .range([props.scss.paddingLeftPx,
            props.scss.widthPx - props.scss.paddingLeftPx - props.scss.paddingRightPx]);
    };
    var getYScale = function () {
        return d3.scaleLinear()
            .domain([props.state.yMin, props.state.yMax])
            .range([props.scss.heightPx - props.scss.paddingTopPx - props.scss.paddingBottomPx,
            props.scss.paddingTopPx]);
    };
    var xScale = getXScale();
    var yScale = getYScale();
    return (React.createElement("svg", { style: getStyle(), width: props.scss.widthPx, height: props.scss.heightPx },
        React.createElement(TimeSeries, { xScale: xScale, yScale: yScale, chartTimeSeries: hpTimeSeriesChartCalculations.convertToOnScreenTimeSeries(props.state.series, props.state.windowUnixFrom, props.state.windowUnixTo, props.scss.widthPx) }),
        displayAxis() && React.createElement(DateTimeAxis, { xScale: xScale, scss: props.scss }),
        displayAxis() && React.createElement(ValueAxis, { yScale: yScale, scss: props.scss })));
};
//# sourceMappingURL=index.js.map