/**
 * Declares default reducer function implementations
 * that can be reused by a concrete screen reducer
 */
import * as _ from 'lodash';
import * as actionTypes from './action-types';
import { EnumTimeSeriesType } from './state/enums';
import { unixIndexMapCalculations } from './calculations/unix-index-map';
import { hpTimeSeriesChartReducerAuxFunctions as auxFunctions, hpTimeSeriesChartReducerAuxFunctions } from './reducers-aux';
import { SetDataAction } from './actions';
var initialState = hpTimeSeriesChartReducerAuxFunctions.buildInitialState();
/**
 * Builds (initial) chart state with several outer settings
 */
var generateRandomData = function (state, action) {
    return setData(state, new SetDataAction([{
            color: "orange",
            name: "Random Series",
            points: auxFunctions.randomContinousUnixTimePoints(action.from, action.to),
            type: EnumTimeSeriesType.Line,
        }]));
};
var setData = function (state, action) {
    var stateWithSeries = {
        series: _.map(action.series, function (el) { return ({
            color: el.color,
            unixFrom: _.isEmpty(el.points) ? Number.MAX_VALUE : _.first(el.points).unix,
            unixTo: _.isEmpty(el.points) ? Number.MIN_VALUE : _.last(el.points).unix,
            points: el.points,
            name: el.name,
            type: el.type,
            unixToIndexMap: unixIndexMapCalculations.createUnixToIndexMap(el.points)
        }); })
    };
    var allValues = _.reduceRight(stateWithSeries.series, function (accumulator, series) {
        return _.concat(accumulator, _.map(series.points, function (el) { return el.value; }));
    }, []);
    var unixFrom = _.min(_.concat(_.map(stateWithSeries.series, function (el) { return el.unixFrom; })));
    var unixTo = _.max(_.concat(_.map(stateWithSeries.series, function (el) { return el.unixTo; })));
    var stateWithUnixFromTo = _.extend(stateWithSeries, {
        dateRangeUnixFrom: unixFrom,
        dateRangeUnixTo: unixTo,
        windowUnixFrom: unixFrom,
        windowUnixTo: unixTo,
        yMin: _.min(allValues),
        yMax: _.max(allValues)
    });
    return _.extend(stateWithSeries, stateWithUnixFromTo);
};
export var hpTimeSeriesChartReducer = function (state, action) {
    if (state === void 0) { state = initialState; }
    switch (action.type) {
        case actionTypes.GENERATE_RANDOM_DATA:
            return generateRandomData(state, action);
        case actionTypes.SET_DATA:
            return setData(state, action);
    }
};
//# sourceMappingURL=reducers.js.map